@@ -21,9 +21,7 @@ package php
 
 import (
 	"context"
-	"crypto/sha1"
 	"fmt"
-	"io"
 	"net"
 	"net/http"
 	"net/http/httputil"
@@ -202,7 +200,7 @@ func (p *Server) Start(ctx context.Context, pidFile *pid.PidFile) (*pid.PidFile,
 			p.StoppedChan <- true
 		}()
 
-		return errors.Wrap(errors.WithStack(runner.Run()), "PHP server exited unexpectedly")
+		return errors.Wrap(runner.Run(), "PHP server exited unexpectedly")
 	}, nil
 }
 
@@ -238,9 +236,3 @@ func (p *Server) Serve(w http.ResponseWriter, r *http.Request, env map[string]st
 	p.proxy.ServeHTTP(w, r)
 	return nil
 }
-
-func name(dir string) string {
-	h := sha1.New()
-	io.WriteString(h, dir)
-	return fmt.Sprintf("%x", h.Sum(nil))
-}
